bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 24. Aventiure
___________________________________________________ #### <Wie Werbel vn– Svemel die botschaft wrben>
| ### o Ecel sine boten zvo dem Rine sande ### do flvgen disiv rnere von lande ze lande ### mit boten harte snellen er bat vn– ovch gebot ### zvo siner hohgezite des holte maniger da den tot
###### 1363 | ### Die boten dannen fuoren vozer Hvnen lant ### zvo den Burgonden dar waren si gesant ### nach drien edelen kvnigen vn– ovch nach ir man ### si solten komen Ecelen des man si do gahen began
###### 1364 | ### Hin ce Bechlaren chomen si geriten ### da diente man in gerne daz enwart da niht <vermiten> ### Ruediger sinen dienest enbot vnd Gotlint ### bi in hin ze Rine vn– ovch ir beider kint
###### 1365 | ### Sine liezens ane gabe von in niht scheiden dan ### daz dester baz gefueren die Ecelen man ### voten vnd ir kinden enbot do Ruediger ### sine hete in so wege deheinen marchgrauen mer
###### 1366 | ### Sin enbuten ovch Prvnhilde dienst vn– gvot ### steteliche triwe vn– willigen mvot ### do si die rede vernamen die boten wolten varn ### si bat div marchgrauinne got von himele bewarn
###### 1367 | ### E daz die boeten vol durch Beierlant ### Wærbel der vil snelle den gvoten bischof vant ### waz der do sinen frivnden hin ze Rine enbot ### daz ist mir niht gewizen niwan sin golt als rot
###### 1368 | ### gab er den boten ze minnen riten er si lie ### do sprach der bischof Pilgerim vn– solt ich si sehen hie ### mit wære wol ze mvote die swester suone min ### wand ich mac vil selten zvo zin komen an den Rin [56a]
###### 1369 | ### Welche wege si fuorten ze Rine durch div lant ### des chan ich niht bescheiden ir siber vn– gewant ### daz en nam in nieman man vorhte ir herren zorn ### so was vil gewaltich der edele kvnic wol geborn
###### 1370 | ### Inre tagen zwelfen chomens an den Rin ### ze Wormez zvo dem lande Werbel vn– Swermlin ### do sagt man div mere den kvnigen vn– ir man ### da chomen bote vremde Gvnther do vragen began
###### 1371 | ### Do sprach der vogt von Rine wer tvot vns daz bechant ### von wannen dise vremden riten in daz lant ### daz en wesse nieman vnz daz si sach ### Hagene von Tronie ze Gvnther do sprach
###### 1372 | ### Vns chemen niwe mære des wil ich iv veriehen ### die Ecelen videlere die han ich hie gesehen ### si hat iwer swester gesendet an den Rin ### si svln vns durch ir <hereren> groz willechomen sin
###### 1373 | ### Si riten al bereite fur den palas dan ### ez gefuoren nie herlicher fursten spileman ### des kvniges ingesinde enphie si sa zehant ### man gab in herberge vnde hiez behalten ir gewant
###### 1374 | ### Ir reischleider waren so rich vnd so wolgetan ### ia mohten si mit eren fur den kvnic gan ### sin wolten ir niht mer da ze hove tragen ### ob ir ieman geruohte die boten hiezen daz sagen
###### 1375 | ### In der selbe maze man ovch lute vant ### die ez vil gerne namen den wart ez gesant ### do leiten an die geste verre bezzer wat ### als ez boten kvniges ze tragene herliche stat
###### 1376 | ### Do gie mit vrlovbe da der kvnich saz ### daz Ecelen gesinde gerne sach man daz ### Hagene zvhtecliche ze den boten sprach ### vn– enpfie si minecliche des sagten im die knappen danch
###### 1377 | ### Durch div kvnden mere vragen er began ### wie si Ecele gehabte vn– die sine <man> ### do sprach der videlere daz lant gestvont nie baz ### noch so vro die lute nv wizzet endeliche daz
###### 1378 | ### Si giengen zvo dem wirte der palas der was vol ### do enphie man die geste so man von rehte sol ### guotlichen gruozen in ander kvnige lant ### Werbel vil der reken da bi Gvnther vant
###### 1379 | ### Der kvnich gezogenlike si gruozen began ### sit willekoemen beide ir Hvnen spileman ### vn– iwer hergesellen wer hat ivch her gesant ### Ecele der riche zvo der Burgonden lant
###### 1380 | ### Si nigen do dem kvnige do sprach Werblin ### dir enbivtet holden dienest der liebe herre min ### vn– Criemhilt din swester her in dize lant ### si habent reken vf guote triwe her gesant
###### 1381 | ### Do sprach der fvrste riche der mere der bin ich vro ### wie gehabet sich Ecele so vragete der degen do [56b] ### vn– Chriemhilt min swester vozer Hvnen lant ### do sprach der videlere div mere tvon ich iv bechant
###### 1382 | ### daz sich noch nie gehabten deheine lûte baz ### danne si sich <gehabent> beide ir svlt wol wizen daz ### vnde allez daz gedigene die magt vn– ovch alle ir man ### si vreuten sich der verte do wir schieden von dan
###### 1383 | ### Genade siner dienste die er mir enboten hat ### vn– miner swester sit ez also stat ### daz si lebent mit vrevden der kvnich vnd sine man ### wand ich doch der mere gevraget sorgende han
###### 1384 | ### Die zwene ivngem kvnige die waren ovch nv komen ### si hete disiv mere alreste do vernomen ### durch siner swester liebe die boten gerne sach ### Giselher der ivnge zvo zin do minneclichen sprach
###### 1385 | ### Ir boten sult vns groz willekomen sin ### ob ir diker woltet her riten an den Rin ### ir fvndet hie die vrivnde die ir gerne moehtet sehen ### iv solte hie ze lande vil wenich leides geschehen
###### 1386 | ### Wir triwen iv aller eren sprach do Swermlin ### ich chvnde iv niht betivten mit den sinnen min ### wie rehte minnecliche iv Ecel enboten hat ### vn– iwer edele swester der dinc in hohen ern stat
###### 1387 | ### Genade vn– triwen mant ivch des kvniges wip ### vn– daz ie wege iwer herze vn– iwer lip ### vnd ze vordrest dem kvnige si wir her gesant ### daz ir geruochet riten in daz Ecelen lant
###### 1388 | ### Daz wir ivch des beten vil vaste vns daz gebot ### Ecel der iv allen daz enbot ### ob ir voch iwer swester niht sehen woltet lan ### so wolt er doch gerne wizen waz er iv hete getan
###### 1389 | ### daz irn also vremdet vn– ovch sine lant ### ob iv div kvniginne wer nie mer bekant ### so moht er doch verdienen daz ir in geruochet sehen ### swenne daz ergienge so wer im liebe geschehen
###### 1390 | ### Do sprach der kvnich Gvnther vber dise siben naht ### do kvnde iv div mere wes ich mich danne bedaht ### mit den minen vrivnden die wile svlt ir gan ### in iwer herberge vn svlt vil guote riwe han
###### 1391 | ### Do sprach aber Werblin vn– mohte daz geschehen ### daz mine vrovwen ê kvnden gesehen ### voten die vil riken ê wir schuofen vns gemach ### Giselher der edele vil harte zvchtechlichen sprach
###### 1392 | ### Daz ensolt iv niemen wenden vn– welt ir fvr si gan ### ir habet miner mvoter willen gar getan ### wan si sihet iv gerne durch die swester min ### vron Kriemhilte ir svlt willekomen sin
###### 1393 | ### Giselher si brahte da er die vrovwen vant ### die boten sach si gerne von der Hvnen lant ### si gruoztes minnecliche durch ir tvgenthaften mvot ### do sagten ir div mere die boten hovbis vn– guot [57a]
###### 1394 | ### Ia enbivtet iv min vrovwe so sprach Swermlin ### dienst vn– triwe moehte daz gesin ### daz si iv diche sehe ir svlt gelovben daz ### so wære ir in der werlte mit deheinen vriunden baz
###### 1395 | ### Do sprach div kvnigin des mach nv niht gesin ### wie gerne ich dike sehe die lieben tohter min ### so ist leider mir ze verre des edelen kvniges wip ### im sin immer selich ir und Ecelen lip
###### 1396 | ### Ir svlt mich lazen wizzen ê irz gervomet hie ### wenne ir wider wellet ine gesach so gerne nie ### boten in langen ziten danne ich iv han gesehen ### die knappen ir do lobeten daz si daz liezen geschehen
###### 1397 | ### Zen herbergen fuoren die von Hunen lant ### do het der kvnich riche nach vrivnden sin gesant ### Gvnther der edele der vragte sine man ### wie in die rede geviele vil maniger sprechen do began
###### 1398 | ### daz er wol mohte riten in Ecelen lant ### daz rieten im die besten di er darvnder vant ### ane Hagnen eine dem was ez grimme leit ### er sprach ce dem kvnige tovgen ir habt iv selben widerseit
###### 1399 | ### Nv ist iv doch gewizzen waz wir haben getan ### wir mvgen in ir sorge zuo Kriemhilte han ### wan ich sluoch ze tode ir man mit miner hant ### wie getorsten wir geriten in daz Ecelen lant
###### 1400 | ### Do sprach der kvnich rike min swester lie den zorn ### mit chusse minnechliche si hat vf vns verchorn ### daz wir ie getaten ê daz si hinnen reit ### enzsi et Hagne iv eim widerseit
###### 1401 | ### Nv lat iv niht betriegen sprach Hagne swes si halt iehen ### die boten von den Hvnen welt ir Criemhilte sehen ### ir mvget wol da verliesen die ere vnd ovch den lip ### ez ist vil lanchreche des kvniges Ecelen lip
###### 1402 | ### Do sprach zuo dem rate der furste Gernot ### sit ir da von schvlden furhtet da der tot ### in Hvnischen riken solten wirz darvmbe lan ### wirn sehen vnser swester daz were vil vbele getan
###### 1403 | ### Do sprach der fvrste Giselher zvo dem degne ### sit ir iv schvldech wizzet vrivnt <Hagene> ### so svlt ir beliben vnd ivch vil wol bewarn ### vn lazet die geturste gen zvo miner swester mit vns varn
###### 1404 | ### Do begvnde zvrnen von Troni der degen ### in wil nicht daz ir fuoret iemen vf den wegen ### der geturre riten mit iv ze hove baz ### sit ir niht welt erwinden ich sol iv wol erzeigen daz
###### 1405 | ### Do sprach der kvchenmeister Rvmolt der degen ### der vremden vnd der kvnden moht er wol heizen pflegen ### nach iwer selbes willen wand ir habet vollen rat ### ich wene niht daz Hagene iuch noch vergiselet hat
###### 1406 | ### Welt ir niht volgen Hagnen iv retet Rvmolt ### wand ich iv bin mit triwen dienstlichen holt [57b] ### daz ir hie svlt beliben durch den willen min– ### vn– lat den kvnich Ezelen dort bi Chriemhilt sin
###### 1407 | ### Wie chond iv in der werlte immer samfte wesen ### ir mvget vor iuren vienden harte wol genesen ### ir svlt mit guoten cleideren zieren wol den lip ### trinket win den besten vn– minnet wetlichiv wip
###### 1408 | ### Darzvo git man iv spise die besten die ie gewan ### in der werlte kvnic deheiner ob des niht moehtet ergan ### ir soltet noch beliben durch iwer schoene wip ### ê ir so kintliche soleet wagen den lip
###### 1409 | ### Des rat ich iv beliben rich sint iwer lant ### man mach iv baz erlosen hie heime div phant ### danne da zen Hvnen wer waiz wie ez da stat ### ir svlt beliben herre daz üst der Rvmoldes rat
###### 1410 | ### Wir wellen niht beliben sprach do Gernot ### sit daz vns min swester so vrivntliche enbot ### vn– Ecele der riche zwi solte wir daz lan ### der dar niht gerne welle der mac hie heime bestan
###### 1411 | ### Des antwurte Hagne lat ivch vnbilden niht ### mine rede darvmbe swie halt iv geschihet ### ich rat iv an den triwen welt ir iv bewarn ### so svlt ir zvo den Hvnen vil werlichen varn
###### 1412 | ### Sit ir niht wellet erwinden so besendet iwer man ### die besten die ir vindet oder indert mvget han ### so wel ich vz in alolen tvsent riter gvot ### so mag iv niht gewerren der argen Kriemhilte mvot
###### 1413 | ### Des wil ich gerne volgen sprach der kvnich zehant ### do hiez er boten riten wite in siniv lant ### do braht man der helde driv tvsent oder mer ### sin wanden niht zerwerben also grozlichiv ser
###### 1414 | ### Si riten vroliche in Gvnthers lant ### man hiez in allen geben ros vnd ovch gewant ### die da varen solten von Burgonden lant ### der konic mit guoten willen do vil manigen guoten riter vant
###### 1415 | ### Do hiez von Troni Hagne Dancwart den bruoder sin ### ir beiden reken ahzech fueren an den Rin ### die komen riterliche harnas vn– gewant ### fuorte die vil snelle in daz Gvnthers lant
###### 1416 | ### Do kom der kuene Volker ein edel spilman ### zvo der hovereise mit drizech siner man ### die heten solich gewete ez mohte ein kvnic tragen ### daz er zen Hvnen wolte daz hiez er Gunthere sagen
###### 1417 | ### Wer der Volker were daz wil ich iv wizzen lan ### er was ein edel herre im was ovch vndertan ### vil der guoten reken in Burgonden lant ### durch daz er <vidlen> chonde was er der spilman genant
###### 1418 | ### Hagne welte tvsent die het er wol bekant ### was in starken sturmen hete gefruomet ir hant ### oder swaz si ie begiengen des het vil gesehen ### den kvnde anders nieman niwan vrumechait iehen [58a]
###### 1419 | ### Die bote Kiemhilte vil sere da verdroz ### wan ir wort ze ir herren div was harte groz ### si gerten tegeliche vrlovbes von dan ### des engvnde in niht Hagene daz was durch liste getan
###### 1420 | ### Er sprach zuo sime herren wil svln daz wol bewarn ### daz wir si lazen riten ê daz wir selbe varn ### dar nach in siben nahten in Ecelen lant ### treit vns iemen argen willen daz wirt vns dester baz erchant
###### 1421 | ### Son mach ovch sich vro Kriemhilt bereiten niht darzvo ### daz vns durch ir rete iemen schaden tuo ### hat aber si den willen ez mag ir leide ergan ### wir fueren mit vns zvo den Hvnen so manigen vzerwelten man
###### 1422 | ### Silt vn– setele vn– allez ir gewant ### daz si fueren wolten in Ecelen lant ### daz was nv gar bereit vil manigem kuenen man ### die boten Kriemhilte hiez man fur Gvntheren gan
###### 1423 | ### Do die boten komen do sprach Gernot ### der kvnich wil des volgen daz vns Ezel her enbot ### wir wellen komen gerne zvo siner hohgezit ### vn– sehen vnser swester daz ir des ane zwivel sint
###### 1424 | ### Do sprach der kvnich Gvnther kvnnet ir vns alle gesagen ### wenne si die hohcit oder in welhen tagen ### wir dar komen solden do sprach Swermlin ### zen nehsten svnewenden sol si vil werlichen sin
###### 1425 | ### Der kvnich in erlovbte des was noch niht geschehen ### ob si wolten gerne vron Prunhilte sehen ### da si fuor si solten mit sinen willen gan ### daz vnderstuont do Volcher daz was ir liebe getan
###### 1426 | ### Ian ist min vrovwe Prunhilt nv niht so wol gemvot ### daz ir si muget schovwen sprach der riter guot ### bitet vns morgen so lat mans doch sehen ### do sis wanden schovwen do kvndes niht geschehen
###### 1427 | ### Do liez der furste riche er was den boten holt ### durch sin selbes tvgende tragen dar sin golt ### vf den breiten schilten der mohter vil han ### ovch wart in richiv gabe von vriunden getan
###### 1428 | ### Giselher vnd Gernot Gere vn– ovch Ortuwin ### daz si ovch milte waren daz taten si wol schin ### also riche gabe si buten die boten an ### daz sis vor ir herren nie getorsten enphahen
###### 1429 | ### Do sprach zuo dem kvnige der bote Swermlin ### her kvnich lat iwer gabe hie ce lande sin ### wir mvgen ir doch niht fuoren min herre ez vns verbot ### daz wir iht gabe nemen ovch ist ez harte luzzel not
###### 1430 | ### Do wart der vogt von Rine da von vil vngemvot ### daz si versprechen wolten so riches kvniges gvot ### do mvosten si enphahen sin golt vnd sin gewant ### daz si mit in fuorten sit in Ecelen lant
###### 1431 | ### Si wolten sehen voten ê daz si schieden dan ### Giselher der iunge braht die spileman ### vor siner mvoter voten die vrovwe enbot do dan ### swaz si eren hete daz wer ir liebe getan [58b]
###### 1432 | ### Do hiez div kvniginne ir boten vnd ir golt ### geben durch Kriemhilde wan der was si holt ### vn– durch den kvnich Ecelen den selben spilman ### si mohtenz gerne enphehen ez was mit triwen getan
###### 1433 | ### Vrlovp genomen heten die boten nv von dan ### von mannen vnd von wiben vrolich als ich nv sagen kan ### si fuoren vnz in Swaben daz hiez si Gernot ### si beleiten sine helde daz ez in niemen missebot
###### 1434 | ### Do sich die von in schieden die ir da solden phlegen ### div Ecelen herschaft si vrideten vf allen wegen ### des nam in nieman ros noch ir gewant ### si ilten harte balde in daz Ecelen lant
###### 1435 | ### Swa si friunde westen daz taten si den kvnt ### daz die von Burgonden in vil kvrcer stvnt ### komen her von Rine in der Hvnen lant ### dem bischof Piligrime wart daz mer ovch bekant
###### 1436 | ### Do si fur Bechlaren die straze nider riten ### man seit ez Ruedigere daz wart niht vermiten ### vn– vron Gottelinde des marchgrauen wip ### daz si sehen solde des wart vil vrolich ir lip
###### 1437 | ### Gahen mit den meren sach man die spilman ### Ecelen si fvnden in siner stat ze Bran ### dienst vber dienste man in vil enbot ### seiten si dem kvnige vor liebe wart er vrevden rot
###### 1438 | ### Do div kvniginne div mere rehte ervant ### daz ir bruodere solden komen in daz lant ### do was ir wol ze mvote si londe die spilman ### mit vil grozer gabe daz was ir ere getan
###### 1439 | ### Si sprach nv saget beide Werbel vn– Swamlin ### welle mine mage zer hochcit willen sin ### der besten die wir ladeten her in dize lant ### nv saget waz redet Hagne do er div mere bevant
###### 1440 | ### Er chom zvo der sprache an einem morgen fruo ### lucel guoter spruche redet er darzvo ### do si die reise lobten her in Hvnen lant ### daz was dem grimmen Hagne gar zem tode genant
###### 1441 | ### Ez koment iwer bruedere die kvnige alle dri ### in herlichem mvote swer mer darmite si ### der mere ich endeclichen nine kan ### ez lobte mir mit miten Volker der spileman
###### 1442 | ### Des enber ich harte lihte sprach des kvniges wip ### daz ich immer hie gesehe den Volkers lip ### Hagnen bin ich wege der ist ein helt guot ### daz wir in hie sehen mvozen des stat hohe mir der mvot
###### 1443 | ### Do gie div kvniginne da si den kvnich sach ### wie rehte minnecliche vrov Kriemhilt do sprach ### wie gevallet iv div mere vil lieber herre min ### des ie min wille gerte nv sol daz gar verendet sin
###### 1444 | ### Din wille der ist min vreude sprach der kvnich do ### nie wart miner selbes mage nie so rehte vro ### ob si immer komen solten her in miniv lant ### durch lieber diner vreude so ist min sorge verswant [59a]
###### 1445 | ### Des kvniges amplûte die hiezen vber al ### mit gesidelen richen palas vn– sal ### gen den lieben gesten die in da solten chomen ### sit wart von in dem kvnige vil michel weinen vernomen

<<< Übersicht <<< vorige Seite nächste Seite >>>